@@ -74,7 +74,7 @@ def unknownMods(inputs, out_dir, knownTable, cluster_dict, modTable, misinc_thre
 					if (tRNA_dict[isodecoder]['sequence'][pos-1] == 'A' and list(modTable[isodecoder][pos].keys())[list(modTable[isodecoder][pos].values()).index(max(modTable[isodecoder][pos].values()))] == 'G' and pos-1 == min(anticodon)):
 						new_inosines_cluster[cluster].append(pos-1)
 						new_inosines_isodecoder[isodecoder].append(pos-1)
-				elif (max(modTable[isodecoder][pos].values()) / sum(modTable[isodecoder][pos].values()) <= 0.95 and not pos-1 == min(anticodon) and not tRNA_dict[isodecoder]['sequence'][pos-1] == 'A'):
+				elif (max(modTable[isodecoder][pos].values()) / sum(modTable[isodecoder][pos].values()) <= 0.95 and not (pos-1 == min(anticodon) and tRNA_dict[isodecoder]['sequence'][pos-1] == 'A')):
 					new_mods_cluster[cluster].append(pos-1) #modTable had 1 based values - convert back to 0 based for mod_lists
 					new_mods_isodecoder[isodecoder].append(pos-1)
 
@@ -250,7 +250,15 @@ def bamMods_mp(out_dir, min_cov, info, mismatch_dict, insert_dict, cluster_dict,
 		modTable_prop_melt['bam'] = inputs
 		modTable_prop_melt.pos = pd.to_numeric(modTable_prop_melt.pos)
 
-		# add coverage per nucelotide from cov
+		# split and parallelize addNA
+		names, dfs = splitTable(modTable_prop_melt)
+		pool = Pool(threads)
+		func = partial(addNA, tRNA_struct, cluster_dict, "mods")
+		modTable_prop_melt = pd.concat(pool.starmap(func, zip(names, dfs)))
+		pool.close()
+		pool.join()
+
+		# format cov table
 		cov_table = pd.DataFrame.from_dict(cov)
 		cov_table['pos'] = cov_table.index
 		cov_table['pos'] = cov_table['pos'].astype(int)
@@ -259,15 +267,18 @@ def bamMods_mp(out_dir, min_cov, info, mismatch_dict, insert_dict, cluster_dict,
 		cov_table_melt['bam'] = inputs
 		cov_table_melt = cov_table_melt[['isodecoder', 'pos', 'bam', 'cov']]
 
-		# split and parallelize addNA
-		names, dfs = splitTable(modTable_prop_melt)
+		# copy and add NAs for correct merging with modTable
+		cov_table_na = cov_table_melt.copy()
+		names, dfs = splitTable(cov_table_na)
 		pool = Pool(threads)
-		func = partial(addNA, tRNA_struct, cluster_dict, "mods")
-		modTable_prop_melt = pd.concat(pool.starmap(func, zip(names, dfs)))
+		func = partial(addNA, tRNA_struct, cluster_dict, "cov")
+		cov_table_na = pd.concat(pool.starmap(func, zip(names, dfs)))
 		pool.close()
 		pool.join()
+
+		# add coverage per nucelotide from cov
+		modTable_prop_melt = pd.merge(modTable_prop_melt, cov_table_na, on = ['isodecoder', 'pos', 'bam'], how = 'left')
 		#modTable_prop_melt = addNA(modTable_prop_melt, tRNA_struct, cluster_dict, "mods")
-		modTable_prop_melt = pd.merge(modTable_prop_melt, cov_table_melt, on = ['isodecoder', 'pos', 'bam'], how = 'left')
 		modTable_prop_melt = modTable_prop_melt[['isodecoder','pos', 'type','proportion','condition', 'bam', 'cov']]
 
 		# Shorten isodecoder names for cov_table after merge with modTable (still long names here), then save
@@ -305,7 +316,7 @@ def bamMods_mp(out_dir, min_cov, info, mismatch_dict, insert_dict, cluster_dict,
 		readthroughTable_melt.dropna(inplace = True)
 		names, dfs = splitTable(readthroughTable_melt)
 		pool = Pool(threads)
-		func = partial(addNA, tRNA_struct, cluster_dict, "stops") #"readthrough")
+		func = partial(addNA, tRNA_struct, cluster_dict, "stops")
 		readthroughTable_melt = pd.concat(pool.starmap(func, zip(names, dfs)))
 		pool.close()
 		pool.join()
@@ -415,9 +426,12 @@ def addNA(tRNA_struct, cluster_dict, data_type, name, table):
 	shortname = "-".join(name.split("-")[:-1]) if not "chr" in name else name
 	for pos in tRNA_struct.loc[shortname].index:
 		if data_type == 'mods':
+			#new = pd.DataFrame({'isodecoder':name, 'pos':pos, 'type':pd.Categorical(['A','C','G','T']), 'proportion':'NA', 'condition':table.condition.iloc[1], 'bam':table.bam.iloc[1], 'cov':'NA'})
 			new = pd.DataFrame({'isodecoder':name, 'pos':pos, 'type':pd.Categorical(['A','C','G','T']), 'proportion':'NA', 'condition':table.condition.iloc[1], 'bam':table.bam.iloc[1]})
 		elif data_type == 'stops':
 			new = pd.DataFrame({'isodecoder':name, 'pos':pos, 'proportion':'NA', 'condition':table.condition.iloc[0], 'bam':table.bam.iloc[0]}, index=[0])
+		elif data_type == 'cov':
+			new = pd.DataFrame({'isodecoder':name, 'pos':pos, 'bam':table.bam.iloc[0], 'cov':'NA'}, index=[0])
 		if tRNA_struct.loc[shortname].iloc[pos-1].struct == 'gap':
 			if not pos == max(tRNA_struct.loc[shortname].index):
 				table.loc[(table.isodecoder == name) & (table.pos >= pos), 'pos'] += 1
@@ -428,26 +442,6 @@ def addNA(tRNA_struct, cluster_dict, data_type, name, table):
 
 	return(table)
 
-# def addNAOLD(tRNA_struct, cluster_dict, data_type_dict, table):
-# # fill mods and stops tables with 'NA' for gapped alignment
-
-# 	grouped = table.groupby('isodecoder')
-# 	for name, group in grouped:
-# 		#cluster = [parent for parent, child in cluster_dict.items() if name in child][0]
-# 		for pos in tRNA_struct.loc[name].index:
-# 			if data_type == 'mods':
-# 				new = pd.DataFrame({'isodecoder':name, 'pos':pos, 'type':pd.Categorical(['A','C','G','T']), 'proportion':'NA', 'condition':group.condition.iloc[1], 'bam':group.bam.iloc[1], 'cov':'NA'})
-# 			elif data_type == 'stops':
-# 				new = pd.DataFrame({'isodecoder':name, 'pos':pos, 'proportion':'NA', 'condition':group.condition.iloc[0], 'bam':group.bam.iloc[0]}, index=[0])
-# 			if tRNA_struct.loc[name].iloc[pos-1].struct == 'gap':
-# 				if not pos == max(tRNA_struct.loc[name].index):
-# 					table.loc[(table.isodecoder == name) & (table.pos >= pos), 'pos'] += 1
-# 				table = table.append(new)
-# 			if not any(table.loc[table.isodecoder == name].pos == pos):
-# 				table = table.append(new)
-
-# 	return(table)
-
 def generateModsTable(sampleGroups, out_dir, name, threads, min_cov, mismatch_dict, insert_dict, cluster_dict, cca, remap, misinc_thresh, knownTable, Inosine_lists, tRNA_dict, Inosine_clusters, unique_isodecoderMMs, splitBool, isodecoder_sizes, clustering):
 # Wrapper function to call countMods_mp with multiprocessing
 
